RankBasedMetricResults
======================

.. currentmodule:: pykeen.evaluation

.. autoclass:: RankBasedMetricResults
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~RankBasedMetricResults.metrics

   .. rubric:: Methods Summary

   .. autosummary::

      ~RankBasedMetricResults.create_random
      ~RankBasedMetricResults.from_ranks
      ~RankBasedMetricResults.key_from_string

   .. rubric:: Attributes Documentation

   .. autoattribute:: metrics

   .. rubric:: Methods Documentation

   .. automethod:: create_random
   .. automethod:: from_ranks
   .. automethod:: key_from_string
